@@ -230,7 +230,7 @@ func (p *ConfigureK0s) validateConfig(h *cluster.Host, configPath string) error
 	var cmd string
 
 	if h.Metadata.K0sBinaryTempFile != "" {
-		oldK0sBinaryPath := h.Configurer.K0sBinaryPath()
+		oldK0sBinaryPath := h.K0sInstallLocation()
 		h.Configurer.SetPath("K0sBinaryPath", h.Metadata.K0sBinaryTempFile)
 		defer func() {
 			h.Configurer.SetPath("K0sBinaryPath", oldK0sBinaryPath)
@@ -301,7 +301,7 @@ func (p *ConfigureK0s) configureK0s(ctx context.Context, h *cluster.Host) error
 		}
 
 		log.Infof("%s: waiting for k0s service to start", h)
-		return retry.AdaptiveTimeout(ctx, retry.DefaultTimeout, node.ServiceRunningFunc(h, h.K0sServiceName()))
+		return retry.WithDefaultTimeout(ctx, node.ServiceRunningFunc(h, h.K0sServiceName()))
 	}
 
 	return nil
