@@ -42,28 +42,19 @@ func (p *InstallWorkers) ShouldRun() bool {
 	return len(p.hosts) > 0
 }
 
-// CleanUp attempts to clean up any changes after a failed install
-func (p *InstallWorkers) CleanUp() {
-	_ = p.After()
-	_ = p.hosts.Filter(func(h *cluster.Host) bool {
-		return !h.Metadata.Ready
-	}).ParallelEach(context.Background(), func(_ context.Context, h *cluster.Host) error {
-		log.Infof("%s: cleaning up", h)
-		if len(h.Environment) > 0 {
-			if err := h.Configurer.CleanupServiceEnvironment(h, h.K0sServiceName()); err != nil {
-				log.Warnf("%s: failed to clean up service environment: %v", h, err)
-			}
-		}
-		if h.Metadata.K0sInstalled && p.IsWet() {
-			if err := h.Exec(h.Configurer.K0sCmdf("reset --data-dir=%s", h.K0sDataDir()), exec.Sudo(h)); err != nil {
-				log.Warnf("%s: k0s reset failed", h)
-			}
-		}
-		return nil
-	})
+// Before runs "before install" hooks for workers
+func (p *InstallWorkers) Before() error {
+	return p.runHooks(context.Background(), "install", "before", p.hosts...)
 }
 
+// After runs "after install" hooks for workers
 func (p *InstallWorkers) After() error {
+	// Run per-host "after install" hooks via the common helper
+	if err := p.runHooks(context.Background(), "install", "after", p.hosts...); err != nil {
+		return err
+	}
+
+	// Invalidate any created join tokens and overwrite token files
 	if NoWait {
 		for _, h := range p.hosts {
 			if h.Metadata.K0sTokenData.Token != "" {
@@ -95,6 +86,26 @@ func (p *InstallWorkers) After() error {
 	return nil
 }
 
+// CleanUp attempts to clean up any changes after a failed install
+func (p *InstallWorkers) CleanUp() {
+	_ = p.hosts.Filter(func(h *cluster.Host) bool {
+		return !h.Metadata.Ready
+	}).ParallelEach(context.Background(), func(_ context.Context, h *cluster.Host) error {
+		log.Infof("%s: cleaning up", h)
+		if len(h.Environment) > 0 {
+			if err := h.Configurer.CleanupServiceEnvironment(h, h.K0sServiceName()); err != nil {
+				log.Warnf("%s: failed to clean up service environment: %v", h, err)
+			}
+		}
+		if h.Metadata.K0sInstalled && p.IsWet() {
+			if err := h.Exec(h.K0sResetCommand(), exec.Sudo(h)); err != nil {
+				log.Warnf("%s: k0s reset failed", h)
+			}
+		}
+		return nil
+	})
+}
+
 // Run the phase
 func (p *InstallWorkers) Run(ctx context.Context) error {
 	for i, h := range p.hosts {
@@ -131,7 +142,7 @@ func (p *InstallWorkers) Run(ctx context.Context) error {
 	err := p.parallelDo(ctx, p.hosts, func(_ context.Context, h *cluster.Host) error {
 		if p.IsWet() || !p.leader.Metadata.DryRunFakeLeader {
 			log.Infof("%s: validating api connection to %s using join token", h, h.Metadata.K0sTokenData.URL)
-			err := retry.AdaptiveTimeout(ctx, 30*time.Second, func(_ context.Context) error {
+			err := retry.WithDefaultTimeout(ctx, func(_ context.Context) error {
 				err := h.Exec(h.Configurer.KubectlCmdf(h, h.K0sDataDir(), "get --raw='/version' --kubeconfig=/dev/stdin"), exec.Sudo(h), exec.Stdin(string(h.Metadata.K0sTokenData.Kubeconfig)))
 				if err != nil {
 					return fmt.Errorf("failed to connect to kubernetes api using the join token - check networking: %w", err)
@@ -190,7 +201,7 @@ func (p *InstallWorkers) Run(ctx context.Context) error {
 		if err != nil {
 			return err
 		}
-		err = p.Wet(h, fmt.Sprintf("install k0s worker with `%s`", strings.ReplaceAll(cmd, h.Configurer.K0sBinaryPath(), "k0s")), func() error {
+		err = p.Wet(h, fmt.Sprintf("install k0s worker with `%s`", strings.ReplaceAll(cmd, h.K0sInstallLocation(), "k0s")), func() error {
 			return h.Exec(cmd, exec.Sudo(h))
 		})
 		if err != nil {
@@ -223,7 +234,7 @@ func (p *InstallWorkers) Run(ctx context.Context) error {
 			log.Infof("%s: waiting for node to become ready", h)
 
 			if p.IsWet() {
-				if err := retry.AdaptiveTimeout(ctx, retry.DefaultTimeout, node.KubeNodeReadyFunc(h)); err != nil {
+				if err := retry.WithDefaultTimeout(ctx, node.KubeNodeReadyFunc(h)); err != nil {
 					return err
 				}
 				h.Metadata.Ready = true
