@@ -32,7 +32,7 @@ func (p *UpgradeWorkers) Title() string {
 func (p *UpgradeWorkers) Prepare(config *v1beta1.Cluster) error {
 	p.Config = config
 	p.leader = p.Config.Spec.K0sLeader()
-	var workers cluster.Hosts = p.Config.Spec.Hosts.Workers()
+	workers := p.Config.Spec.Hosts.Workers()
 	log.Debugf("%d workers in total", len(workers))
 	p.hosts = workers.Filter(func(h *cluster.Host) bool {
 		if h.Metadata.K0sBinaryTempFile == "" {
@@ -59,6 +59,22 @@ func (p *UpgradeWorkers) ShouldRun() bool {
 	return len(p.hosts) > 0
 }
 
+// Before runs "before upgrade" hooks for worker hosts that need upgrade
+func (p *UpgradeWorkers) Before() error {
+	if len(p.hosts) == 0 {
+		return nil
+	}
+	return p.runHooks(context.Background(), "upgrade", "before", p.hosts...)
+}
+
+// After runs "after upgrade" hooks for worker hosts that were upgraded
+func (p *UpgradeWorkers) After() error {
+	if len(p.hosts) == 0 {
+		return nil
+	}
+	return p.runHooks(context.Background(), "upgrade", "after", p.hosts...)
+}
+
 // CleanUp cleans up the environment override files on hosts
 func (p *UpgradeWorkers) CleanUp() {
 	if !p.IsWet() {
@@ -78,10 +94,11 @@ func (p *UpgradeWorkers) CleanUp() {
 // Run the phase
 func (p *UpgradeWorkers) Run(ctx context.Context) error {
 	// Upgrade worker hosts parallelly in 10% chunks
-	concurrentUpgrades := int(math.Floor(float64(len(p.hosts)) * 0.10))
+	concurrentUpgrades := int(math.Floor(float64(len(p.hosts)) * float64(p.Config.Spec.Options.Concurrency.WorkerDisruptionPercent/100)))
 	if concurrentUpgrades == 0 {
 		concurrentUpgrades = 1
 	}
+	concurrentUpgrades = min(concurrentUpgrades, p.Config.Spec.Options.Concurrency.Limit)
 
 	log.Infof("Upgrading max %d workers in parallel", concurrentUpgrades)
 	return p.hosts.BatchedParallelEach(ctx, concurrentUpgrades,
@@ -113,12 +130,21 @@ func (p *UpgradeWorkers) cordonWorker(_ context.Context, h *cluster.Host) error
 func (p *UpgradeWorkers) uncordonWorker(_ context.Context, h *cluster.Host) error {
 	if !p.IsWet() {
 		p.DryMsg(h, "uncordon node")
+		if t := p.Config.Spec.Options.EvictTaint; t.Enabled {
+			p.DryMsgf(h, "remove taint %s", t.String())
+		}
 		return nil
 	}
 	log.Debugf("%s: uncordon", h)
 	if err := p.leader.UncordonNode(h); err != nil {
 		return fmt.Errorf("uncordon node: %w", err)
 	}
+	if t := p.Config.Spec.Options.EvictTaint; t.Enabled {
+		log.Debugf("%s: remove taint: %s", h, t.String())
+		if err := p.leader.RemoveTaint(h, t.String()); err != nil {
+			return fmt.Errorf("remove taint: %w", err)
+		}
+	}
 	return nil
 }
 
@@ -127,12 +153,24 @@ func (p *UpgradeWorkers) drainWorker(_ context.Context, h *cluster.Host) error {
 		log.Debugf("%s: not draining because --no-drain given", h)
 		return nil
 	}
+	if t := p.Config.Spec.Options.EvictTaint; t.Enabled {
+		log.Debugf("%s: add taint: %s", h, t.String())
+		err := p.Wet(h, "add taint "+t.String(), func() error {
+			if err := p.leader.AddTaint(h, t.String()); err != nil {
+				return fmt.Errorf("add taint: %w", err)
+			}
+			return nil
+		})
+		if err != nil {
+			return err
+		}
+	}
 	if !p.IsWet() {
 		p.DryMsg(h, "drain node")
 		return nil
 	}
 	log.Debugf("%s: drain", h)
-	if err := p.leader.DrainNode(h); err != nil {
+	if err := p.leader.DrainNode(h, p.Config.Spec.Options.Drain); err != nil {
 		return fmt.Errorf("drain node: %w", err)
 	}
 	return nil
@@ -155,7 +193,7 @@ func (p *UpgradeWorkers) upgradeWorker(ctx context.Context, h *cluster.Host) err
 			return err
 		}
 
-		if err := retry.AdaptiveTimeout(ctx, retry.DefaultTimeout, node.ServiceStoppedFunc(h, h.K0sServiceName())); err != nil {
+		if err := retry.WithDefaultTimeout(ctx, node.ServiceStoppedFunc(h, h.K0sServiceName())); err != nil {
 			return err
 		}
 
@@ -209,7 +247,7 @@ func (p *UpgradeWorkers) upgradeWorker(ctx context.Context, h *cluster.Host) err
 			log.Debugf("%s: not waiting because --no-wait given", h)
 		} else {
 			log.Infof("%s: waiting for node to become ready again", h)
-			if err := retry.AdaptiveTimeout(ctx, retry.DefaultTimeout, node.KubeNodeReadyFunc(h)); err != nil {
+			if err := retry.WithDefaultTimeout(ctx, node.KubeNodeReadyFunc(h)); err != nil {
 				return fmt.Errorf("node did not become ready: %w", err)
 			}
 		}
