@@ -1,12 +1,12 @@
 package cluster
 
 import (
-    "context"
-    "fmt"
-    "net/url"
-    gos "os"
-    gopath "path"
-    "slices"
+	"context"
+	"fmt"
+	"net/url"
+	gos "os"
+	gopath "path"
+	"slices"
 	"strings"
 	"time"
 
@@ -37,6 +37,7 @@ type Host struct {
 	KubeletRootDir   string            `yaml:"kubeletRootDir,omitempty"`
 	Environment      map[string]string `yaml:"environment,flow,omitempty"`
 	UploadBinary     bool              `yaml:"uploadBinary,omitempty"`
+	UseExistingK0s   bool              `yaml:"useExistingK0s,omitempty"`
 	K0sBinaryPath    string            `yaml:"k0sBinaryPath,omitempty"`
 	K0sInstallPath   string            `yaml:"k0sInstallPath,omitempty"`
 	K0sDownloadURL   string            `yaml:"k0sDownloadURL,omitempty"`
@@ -123,13 +124,43 @@ func (h *Host) Validate() error {
 		return err
 	}
 
-	return validation.ValidateStruct(h,
+	if err := validation.ValidateStruct(h,
 		validation.Field(&h.Role, validation.In("controller", "worker", "controller+worker", "single").Error("unknown role "+h.Role)),
 		validation.Field(&h.PrivateAddress, is.IP),
 		validation.Field(&h.Files),
 		validation.Field(&h.NoTaints, validation.When(h.Role != "controller+worker", validation.NotIn(true).Error("noTaints can only be true for controller+worker role"))),
 		validation.Field(&h.InstallFlags, validation.Each(validation.By(validateBalancedQuotes))),
-	)
+	); err != nil {
+		return err
+	}
+
+	if h.UseExistingK0s {
+		errs := validation.Errors{}
+		if h.UploadBinary {
+			errs["uploadBinary"] = fmt.Errorf("uploadBinary cannot be true when useExistingK0s is true")
+		}
+		if h.K0sBinaryPath != "" {
+			errs["k0sBinaryPath"] = fmt.Errorf("k0sBinaryPath cannot be set when useExistingK0s is true")
+		}
+		if h.K0sDownloadURL != "" {
+			errs["k0sDownloadURL"] = fmt.Errorf("k0sDownloadURL cannot be set when useExistingK0s is true")
+		}
+		if len(errs) > 0 {
+			return errs
+		}
+	}
+
+	return nil
+}
+
+// ResolveUploadFiles resolves host file sources relative to baseDir.
+func (h *Host) ResolveUploadFiles(baseDir string) error {
+	for _, f := range h.Files {
+		if err := f.ResolveRelativeTo(baseDir); err != nil {
+			return err
+		}
+	}
+	return nil
 }
 
 type configurer interface {
@@ -203,6 +234,13 @@ type HostMetadata struct {
 	DryRunFakeLeader  bool
 }
 
+// Resolve prepares host-scoped data after unmarshalling by resolving upload files.
+func (h *Host) Resolve(baseDir string) error {
+	return h.ResolveUploadFiles(baseDir)
+}
+
+// UnmarshalYAML sets in some sane defaults when unmarshaling the data from yaml
+
 // UnmarshalYAML sets in some sane defaults when unmarshaling the data from yaml
 func (h *Host) UnmarshalYAML(unmarshal func(interface{}) error) error {
 	type host Host
@@ -686,26 +724,26 @@ func (h *Host) FlagsChanged() bool {
 
 // HasHooks returns true when the host has hooks defined for the action and stage.
 func (h *Host) HasHooks(action, stage string) bool {
-    return len(h.Hooks.ForActionAndStage(action, stage)) > 0
+	return len(h.Hooks.ForActionAndStage(action, stage)) > 0
 }
 
 // RunHooks runs the hooks for the given action and stage (such as "apply", "before" would run the "before apply" hooks).
 // It respects context cancellation between hook executions.
 func (h *Host) RunHooks(ctx context.Context, action, stage string) error {
-    commands := h.Hooks.ForActionAndStage(action, stage)
-    if len(commands) == 0 {
-        return nil
-    }
-    for _, cmd := range commands {
-        // Abort early if the context has been canceled.
-        if err := ctx.Err(); err != nil {
-            return err
-        }
+	commands := h.Hooks.ForActionAndStage(action, stage)
+	if len(commands) == 0 {
+		return nil
+	}
+	for _, cmd := range commands {
+		// Abort early if the context has been canceled.
+		if err := ctx.Err(); err != nil {
+			return err
+		}
 
-        log.Infof("%s: running %s %s hook: %q", h, stage, action, cmd)
-        if err := h.Exec(cmd); err != nil {
-            return fmt.Errorf("failed to execute hook %q for action %q stage %q on host %s: %w", cmd, action, stage, h.Address(), err)
-        }
-    }
-    return nil
+		log.Infof("%s: running %s %s hook: %q", h, stage, action, cmd)
+		if err := h.Exec(cmd); err != nil {
+			return fmt.Errorf("failed to execute hook %q for action %q stage %q on host %s: %w", cmd, action, stage, h.Address(), err)
+		}
+	}
+	return nil
 }
