@@ -17,6 +17,7 @@ import (
 	"github.com/k0sproject/k0sctl/pkg/retry"
 	"github.com/k0sproject/rig/exec"
 	"github.com/k0sproject/version"
+	log "github.com/sirupsen/logrus"
 	"gopkg.in/yaml.v2"
 )
 
@@ -158,7 +159,7 @@ func (k *K0s) GenerateToken(ctx context.Context, h *Host, role string, expiry ti
 	}
 
 	var token string
-	err := retry.AdaptiveTimeout(ctx, retry.DefaultTimeout, func(_ context.Context) error {
+	err := retry.WithDefaultTimeout(ctx, func(_ context.Context) error {
 		output, err := h.ExecOutput(h.Configurer.K0sCmdf("token create %s", k0sFlags.Join()), exec.HideOutput(), exec.Sudo(h))
 		if err != nil {
 			return fmt.Errorf("create token: %w", err)
@@ -198,7 +199,11 @@ func ParseToken(s string) (TokenData, error) {
 	if err != nil {
 		return data, fmt.Errorf("failed to create a reader for token: %w", err)
 	}
-	defer gzr.Close()
+	defer func() {
+		if err := gzr.Close(); err != nil {
+			log.Warnf("failed to close token gzip reader: %v", err)
+		}
+	}()
 
 	c, err := io.ReadAll(gzr)
 	if err != nil {
