@@ -6,7 +6,6 @@ import (
 	"errors"
 	"fmt"
 	"io"
-	"os"
 	"path"
 	"regexp"
 	"strings"
@@ -73,14 +72,43 @@ type Reader struct {
 }
 
 func name(r io.Reader) string {
-	if n, ok := r.(*os.File); ok {
-		return n.Name()
+	type named interface {
+		Name() string
+	}
+	if n, ok := r.(named); ok {
+		if nn := n.Name(); nn != "" {
+			return nn
+		}
 	}
 	return "manifest"
 }
 
+// ParseOption configures optional behavior for Parse.
+type ParseOption func(*parseOptions)
+
+type parseOptions struct {
+	origin string
+}
+
+// WithOrigin overrides the origin name for resources parsed from the reader.
+func WithOrigin(origin string) ParseOption {
+	return func(po *parseOptions) {
+		po.origin = origin
+	}
+}
+
 // Parse parses Kubernetes resource definitions from the provided input stream. They are then available via the Resources() or GetResources(apiVersion, kind) methods.
-func (r *Reader) Parse(input io.Reader) error {
+func (r *Reader) Parse(input io.Reader, opts ...ParseOption) error {
+	po := &parseOptions{}
+	for _, opt := range opts {
+		opt(po)
+	}
+
+	origin := po.origin
+	if origin == "" {
+		origin = name(input)
+	}
+
 	yamlReader := yamlutil.NewYAMLReader(bufio.NewReader(input))
 
 	for {
@@ -101,16 +129,17 @@ func (r *Reader) Parse(input io.Reader) error {
 			if r.IgnoreErrors {
 				continue
 			}
-			return fmt.Errorf("failed to decode resource %s: %w", name(input), err)
+			return fmt.Errorf("failed to decode resource %s: %w", origin, err)
 		}
 
 		if rd.APIVersion == "" || rd.Kind == "" {
 			if r.IgnoreErrors {
 				continue
 			}
-			return fmt.Errorf("missing apiVersion or kind in resource %s", name(input))
+			return fmt.Errorf("missing apiVersion or kind in resource %s", origin)
 		}
 
+		rd.Origin = origin
 		// Store the raw chunk
 		rd.Raw = append([]byte{}, rawChunk...)
 		r.manifests = append(r.manifests, rd)
@@ -120,13 +149,18 @@ func (r *Reader) Parse(input io.Reader) error {
 }
 
 // ParseString parses Kubernetes resource definitions from the provided string.
-func (r *Reader) ParseString(input string) error {
-	return r.Parse(strings.NewReader(input))
+func (r *Reader) ParseString(input string, opts ...ParseOption) error {
+	return r.Parse(strings.NewReader(input), opts...)
 }
 
 // ParseBytes parses Kubernetes resource definitions from the provided byte slice.
-func (r *Reader) ParseBytes(input []byte) error {
-	return r.Parse(bytes.NewReader(input))
+func (r *Reader) ParseBytes(input []byte, opts ...ParseOption) error {
+	return r.Parse(bytes.NewReader(input), opts...)
+}
+
+// ParseBytesWithOrigin parses raw bytes and attributes them to the provided origin.
+func (r *Reader) ParseBytesWithOrigin(input []byte, origin string) error {
+	return r.ParseBytes(input, WithOrigin(origin))
 }
 
 // Resources returns all parsed Kubernetes resource definitions.
