@@ -49,18 +49,15 @@ func TestContext(t *testing.T) {
 }
 
 func TestTimeout(t *testing.T) {
-	ctx, cancel := context.WithCancel(context.Background())
-	defer cancel()
-
 	t.Run("succeeds before timeout", func(t *testing.T) {
-		err := Timeout(ctx, 10*time.Second, func(_ context.Context) error {
+		err := Timeout(context.Background(), 10*time.Second, func(_ context.Context) error {
 			return nil
 		})
 		require.NoError(t, err)
 	})
 
 	t.Run("fails on timeout", func(t *testing.T) {
-		err := Timeout(ctx, 1*time.Millisecond, func(_ context.Context) error {
+		err := Timeout(context.Background(), 1*time.Millisecond, func(_ context.Context) error {
 			time.Sleep(2 * time.Millisecond)
 			return errors.New("some error")
 		})
@@ -69,7 +66,7 @@ func TestTimeout(t *testing.T) {
 
 	t.Run("stops retrying on ErrAbort", func(t *testing.T) {
 		var counter int
-		err := Timeout(ctx, 10*time.Second, func(_ context.Context) error {
+		err := Timeout(context.Background(), 10*time.Second, func(_ context.Context) error {
 			counter++
 			if counter == 2 {
 				return errors.Join(ErrAbort, errors.New("some error"))
@@ -78,6 +75,43 @@ func TestTimeout(t *testing.T) {
 		})
 		assert.Error(t, err, "foo")
 	})
+
+	t.Run("respects parent deadline", func(t *testing.T) {
+		parentCtx, cancel := context.WithTimeout(context.Background(), 10*time.Millisecond)
+		defer cancel()
+
+		start := time.Now()
+		err := Timeout(parentCtx, 50*time.Millisecond, func(child context.Context) error {
+			<-child.Done()
+			return child.Err()
+		})
+		elapsed := time.Since(start)
+
+		assert.Error(t, err)
+		assert.Less(t, elapsed, 50*time.Millisecond)
+	})
+
+	t.Run("applies new timeout when parent has none", func(t *testing.T) {
+		start := time.Now()
+		err := Timeout(context.Background(), 10*time.Millisecond, func(_ context.Context) error {
+			time.Sleep(20 * time.Millisecond)
+			return errors.New("some error")
+		})
+		elapsed := time.Since(start)
+
+		assert.Error(t, err)
+		assert.GreaterOrEqual(t, elapsed.Milliseconds(), int64(10))
+	})
+
+	t.Run("does not add deadline when timeout disabled", func(t *testing.T) {
+		var deadlineSet bool
+		err := Timeout(context.Background(), 0, func(ctx context.Context) error {
+			_, deadlineSet = ctx.Deadline()
+			return nil
+		})
+		require.NoError(t, err)
+		assert.False(t, deadlineSet)
+	})
 }
 
 func TestTimes(t *testing.T) {
@@ -118,66 +152,21 @@ func TestTimes(t *testing.T) {
 	})
 }
 
-func TestAdaptiveTimeout(t *testing.T) {
+func TestWithDefaultTimeout(t *testing.T) {
 	ctx, cancel := context.WithCancel(context.Background())
 	defer cancel()
 
-	t.Run("uses existing timeout if present", func(t *testing.T) {
-		parentCtx, parentCancel := context.WithTimeout(ctx, 10*time.Millisecond)
-		defer parentCancel()
+	old := DefaultTimeout
+	DefaultTimeout = 5 * time.Millisecond
+	defer func() { DefaultTimeout = old }()
 
-		start := time.Now()
-		err := AdaptiveTimeout(parentCtx, 50*time.Millisecond, func(_ context.Context) error {
-			time.Sleep(20 * time.Millisecond) // Should be cut off by parent timeout
-			return errors.New("some error")
-		})
-		elapsed := time.Since(start)
-
-		assert.Error(t, err, "some error")
-		assert.Less(t, elapsed.Milliseconds(), int64(50), "should use parent timeout")
+	start := time.Now()
+	err := WithDefaultTimeout(ctx, func(_ context.Context) error {
+		time.Sleep(10 * time.Millisecond)
+		return errors.New("fail")
 	})
+	elapsed := time.Since(start)
 
-	t.Run("applies new timeout if no parent timeout exists", func(t *testing.T) {
-		start := time.Now()
-		err := AdaptiveTimeout(ctx, 10*time.Millisecond, func(_ context.Context) error {
-			time.Sleep(20 * time.Millisecond) // Should be cut off by the new timeout
-			return errors.New("some error")
-		})
-		elapsed := time.Since(start)
-
-		assert.Error(t, err, "some error")
-		assert.GreaterOrEqual(t, elapsed.Milliseconds(), int64(10), "should use new timeout")
-	})
-
-	t.Run("uses the earlier deadline if both parent and new timeout exist", func(t *testing.T) {
-		parentCtx, parentCancel := context.WithTimeout(ctx, 20*time.Millisecond)
-		defer parentCancel()
-
-		start := time.Now()
-		err := AdaptiveTimeout(parentCtx, 50*time.Millisecond, func(_ context.Context) error {
-			time.Sleep(30 * time.Millisecond) // Should be cut off by the parent context
-			return errors.New("some error")
-		})
-		elapsed := time.Since(start)
-
-		assert.Error(t, err, "some error")
-		assert.Less(t, elapsed.Milliseconds(), int64(50), "should use parent timeout of 20ms")
-	})
-
-	t.Run("succeeds before timeout", func(t *testing.T) {
-		err := AdaptiveTimeout(ctx, 10*time.Second, func(_ context.Context) error {
-			return nil
-		})
-		require.NoError(t, err)
-	})
-
-	t.Run("stops retrying on ErrAbort", func(t *testing.T) {
-		var counter int
-		err := AdaptiveTimeout(ctx, 10*time.Second, func(_ context.Context) error {
-			counter++
-			return errors.Join(ErrAbort, errors.New("some error"))
-		})
-		assert.Error(t, err, "some error")
-		assert.Equal(t, 1, counter, "should stop retrying on ErrAbort")
-	})
+	assert.Error(t, err)
+	assert.GreaterOrEqual(t, elapsed.Milliseconds(), int64(5))
 }
